@@ -18,7 +18,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.26.2.1 2004/03/17 02:47:13 muppetman Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.30 2004/05/11 17:41:12 kaffeetisch Exp $
  */
 
 #ifndef _GTK2PERL_H_
@@ -31,6 +31,10 @@
 #define GDK_TYPE_REGION (gtk2perl_gdk_region_get_type ())
 GType gtk2perl_gdk_region_get_type (void) G_GNUC_CONST;
 
+/* custom GType for PangoLayoutIter */
+#define PANGO_TYPE_LAYOUT_ITER (gtk2perl_pango_layout_iter_get_type ())
+GType gtk2perl_pango_layout_iter_get_type (void) G_GNUC_CONST;
+
 #include "gtk2perl-autogen.h"
 #include "gtk2perl-versions.h"
 
@@ -70,6 +74,12 @@ SV * newSVGdkBitmap (GdkBitmap * bitmap);
 SV * newSVGdkBitmap_noinc (GdkBitmap * bitmap);
 #define newSVGdkBitmap_ornull(b) (b ? newSVGdkBitmap (b) : Nullsv)
 
+/* exported for GtkGC */
+SV * newSVGdkGCValues (GdkGCValues * v);
+void SvGdkGCValues (SV * data, GdkGCValues * v, GdkGCValuesMask * m);
+
+/* exported for various other parts of pango */
+SV * newSVPangoRectangle (PangoRectangle * rectangle);
 
 /*
  * GdkAtom, an opaque pointer
@@ -133,9 +143,6 @@ SV * newSVGtkTargetList (GtkTargetList * list);
 GtkTargetList * SvGtkTargetList (SV * sv);
 #define SvGtkTargetList_ornull(sv)	(((sv) && SvOK (sv)) ? SvGtkTargetList (sv) : NULL)
 
-SV * newSVGtkTargetEntry (GtkTargetEntry * entry);
-GtkTargetEntry * SvGtkTargetEntry (SV * sv);
-
 /*
  * exported so Gnome2 can reuse it in wrappers.  other modules might want to
  * do the same.  the callback for it needn't worry about param_types or
